summaryrefslogtreecommitdiffstats
path: root/sys/dev/acpica/acpi_ec.c
diff options
context:
space:
mode:
authoriwasaki <iwasaki@FreeBSD.org>2002-11-27 18:09:20 +0000
committeriwasaki <iwasaki@FreeBSD.org>2002-11-27 18:09:20 +0000
commit05cb8cd7b7d41fa96a64a0f8b120806eb4fb0933 (patch)
tree4bace62f2c1b2923ceef90efb5b5547a7086ee61 /sys/dev/acpica/acpi_ec.c
parent10fb1b40ac2c40a3ce01db48e82a02380186cda2 (diff)
downloadFreeBSD-src-05cb8cd7b7d41fa96a64a0f8b120806eb4fb0933.zip
FreeBSD-src-05cb8cd7b7d41fa96a64a0f8b120806eb4fb0933.tar.gz
Resolve conflicts arising from the ACPI CA 20021118 import.
Diffstat (limited to 'sys/dev/acpica/acpi_ec.c')
-rw-r--r--sys/dev/acpica/acpi_ec.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/dev/acpica/acpi_ec.c b/sys/dev/acpica/acpi_ec.c
index f41cebf..680d3f4 100644
--- a/sys/dev/acpica/acpi_ec.c
+++ b/sys/dev/acpica/acpi_ec.c
@@ -254,8 +254,8 @@ EcLock(struct acpi_ec_softc *sc)
{
ACPI_STATUS status;
- /* XXX WAIT_FOREVER is probably a bad idea, what is a better time? */
- if (ACPI_SUCCESS(status = AcpiAcquireGlobalLock(WAIT_FOREVER, &sc->ec_lockhandle)))
+ /* XXX ACPI_WAIT_FOREVER is probably a bad idea, what is a better time? */
+ if (ACPI_SUCCESS(status = AcpiAcquireGlobalLock(ACPI_WAIT_FOREVER, &sc->ec_lockhandle)))
(sc)->ec_locked = 1;
return(status);
OpenPOWER on IntegriCloud